# to do

* sales_order gui incluant product. 
    tous les produits sont dispo en grille, 
    l'user ajoute des quantités.

* bakery_batch
    pour définir les cuissons (nom, position)

* bakery_alloction
    disable entry si batch non défini pour ce produit.

* rapports de pesées.

* gui order2
    - gérer les copier coller
    - gérer l'ajout et la suppression de lignes
    - modifier client dans l'index ?
    
    